==> matita_0.4.98.orig.tar.gz: matita-0.4.98/components/library/coercDb.mli <==
(* Copyright (C) 2000, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://cs.unibo.it/helm/.
 *)


 (** THIS MODULE SHOULD BE USED ONLY BY CoercGraph/CicCoercion/librarySync
  * 
  *   and may be merged with CicCoercion...
  *  
  * **)


  (** XXX WARNING: non-reentrant *)
type coerc_carr = 
  | Uri of UriManager.uri (* const, mutind, mutconstr *)
  | Sort of Cic.sort (* Prop, Set, Type *) 
  | Term of Cic.term (* nothing supported *)
  | Fun of int
;;
  
exception EqCarrNotImplemented of string Lazy.t
exception EqCarrOnNonMetaClosed
val eq_carr: ?exact:bool -> coerc_carr -> coerc_carr -> bool
val coerc_carr_of_term: Cic.term -> coerc_carr
val name_of_carr: coerc_carr -> string
val uri_of_carr: coerc_carr -> UriManager.uri option

val to_list:
  unit -> 
    (coerc_carr * coerc_carr * (UriManager.uri * int) list) list

val add_coercion:
  coerc_carr * coerc_carr * UriManager.uri * int -> unit

val remove_coercion:
  (coerc_carr * coerc_carr * UriManager.uri * int -> bool) -> unit

val find_coercion: 
  (coerc_carr * coerc_carr -> bool) -> (UriManager.uri * int) list 
    
val is_a_coercion: UriManager.uri -> bool
val is_a_coercion': Cic.term -> bool
val is_a_coercion_to_funclass: Cic.term -> int option
val get_carr: UriManager.uri -> coerc_carr * coerc_carr

val term_of_carr: coerc_carr -> Cic.term

==> matita_0.5.3.orig.tar.gz: matita-0.5.3/components/library/coercDb.mli <==
(* Copyright (C) 2000, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://cs.unibo.it/helm/.
 *)


type coerc_carr = private 
  | Uri of UriManager.uri (* const, mutind, mutconstr *)
  | Sort of Cic.sort (* Prop, Set, Type *) 
  | Fun of int
  | Dead
;;
  
val eq_carr: ?exact:bool -> coerc_carr -> coerc_carr -> bool
val string_of_carr: coerc_carr -> string

(* takes a term in whnf ~delta:false and a desired ariety *)
val coerc_carr_of_term: Cic.term -> int -> coerc_carr 

val to_list:
  unit -> 
    (coerc_carr * coerc_carr * (UriManager.uri * int * int) list) list

type coerc_db
val dump: unit -> coerc_db
val restore: coerc_db -> unit

(* src carr, tgt carr, uri, saturations, coerced position 
 * invariant:
 *   if the constant pointed by uri has n argments
 *   n = coerced position + saturations + FunClass arity
 *)

type saturations = int
type coerced_pos = int
type coercion_entry = 
  coerc_carr * coerc_carr * UriManager.uri * saturations * coerced_pos
val add_coercion: coercion_entry -> unit
val remove_coercion: (coercion_entry -> bool) -> unit

val find_coercion: 
  (coerc_carr * coerc_carr -> bool) -> (UriManager.uri * int) list 
    
val is_a_coercion: Cic.term -> coercion_entry option
